/*
 * Copyright (C) 2022 The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

syntax = "proto3";

package com.android.server.wm.shell;

import "frameworks/base/core/proto/android/server/windowmanagerservice.proto";

option java_multiple_files = true;

/* Represents a file full of transition entries.
   Encoded, it should start with 0x9 0x57 0x49 0x4e 0x54 0x52 0x41 0x43 0x45 (.TRNTRACE), such
   that it can be easily identified. */
message TransitionTraceProto {

  /* constant; MAGIC_NUMBER = (long) MAGIC_NUMBER_H << 32 | MagicNumber.MAGIC_NUMBER_L
     (this is needed because enums have to be 32 bits and there's no nice way to put 64bit
      constants into .proto files. */
  enum MagicNumber {
    INVALID = 0;
    MAGIC_NUMBER_L = 0x544e5254;  /* TRNT (little-endian ASCII) */
    MAGIC_NUMBER_H = 0x45434152;  /* RACE (little-endian ASCII) */
  }

  fixed64 magic_number = 1;  /* Must be the first field, set to value in MagicNumber */
  int64 timestamp = 2; /* The timestamp of when the trace was started. */
  repeated Transition transition = 3;
}

message Transition {

  enum State {
    COLLECTING = 0;
    PENDING = -1;
    STARTED = 1;
    PLAYING = 2;
    ABORT = 3;
    FINISHED = 4;
  }

  int32 id = 1;
  int32 transition_type = 2;
  int64 timestamp = 3;
  State state = 5;
  int32 flags = 6;
  repeated ChangeInfo change = 7;
  uint64 start_transaction_id = 8;
  uint64 finish_transaction_id = 9;
}

message ChangeInfo {
  com.android.server.wm.IdentifierProto window_identifier = 1;
  int32 transit_mode = 2;
  bool has_changed = 3;
  int32 change_flags = 4;
}
